@@ -5,6 +5,7 @@ use warnings;
 
 use MooseX::Types::Common::String qw(NonEmptyStr);
 use MooseX::Types::Moose qw(Str Int RegexpRef);
+use Test::BDD::Cucumber::Definitions qw(S);
 use Try::Tiny;
 
 use MooseX::Types (
@@ -20,7 +21,7 @@ use MooseX::Types (
     ]
 );
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 subtype(
     HttpHeader,
@@ -74,6 +75,18 @@ subtype(
     }
 );
 
+coerce(
+    HttpString,
+    from Str,
+    via {
+        my $value = $_;
+
+        $value =~ s/S\{ (.+?) \}/S->{scenario}->{$1} || ''/gxe;
+
+        return $value;
+    }
+);
+
 subtype(
     HttpRegexp,
     as RegexpRef,
